# coding: utf8
from __future__ import unicode_literals


ADVERBS_IRREG = {
    "best": ("well",),
    "better": ("well",),
    "deeper": ("deeply",),
    "farther": ("far",),
    "further": ("far",),
    "harder": ("hard",),
    "hardest": ("hard",)
}
